@@ -1,13 +1,14 @@
-import requests
 import json
 import os
-import tldextract
-import hvac
-from loguru import logger
-from tenacity import retry, wait_random, stop_after_attempt
-import zx
 import shutil
 
+import hvac
+import requests
+import tldextract
+import zx
+from loguru import logger
+from tenacity import retry, stop_after_attempt, wait_random
+
 
 class RundeckJobs(object):
     def __init__(
@@ -19,11 +20,12 @@ class RundeckJobs(object):
     wait_random_range: tuple = (60, 180)
     number_of_retries: int = 3
 
-    @logger.catch
     def search_uptimerobot(
             self,
-            deployment_action: str = os.environ.get('RD_OPTION_DEPLOYMENT_ACTION'),
-            uptimerobot_api_key: str = os.environ.get("RD_OPTION_UPTIMEROBOT_API_KEY"),
+            deployment_action: str = os.environ.get(
+                'RD_OPTION_DEPLOYMENT_ACTION'),
+            uptimerobot_api_key: str = os.environ.get(
+                "RD_OPTION_UPTIMEROBOT_API_KEY"),
             fqdn: str = os.environ.get("RD_OPTION_FQDN"),
             force_apply: bool = bool(os.environ.get('RD_OPTION_FORCE_APPLY'))):
         if deployment_action != 'apply':
@@ -46,30 +48,37 @@ class RundeckJobs(object):
             print("Force apply is requested, ignoring check results")
             exit(0)
         else:
-            print(f"{fqdn} is alive, want to force redeployment? then change option `force_apply` value to `true`")
+            print(
+                f"{fqdn} is alive, want to force redeployment? then change option `force_apply` value to `true`")
             exit(1)
 
-    @logger.catch
     @retry(wait=wait_random(*wait_random_range), stop=stop_after_attempt(number_of_retries))
     def terraform_cloud_workspace(
             self,
-            pg_user: str = os.environ.get('RD_OPTION_TERRAFORM_PG_BACKEND_USER'),
-            pg_password: str = os.environ.get('RD_OPTION_TERRAFORM_PG_BACKEND_PASSWORD'),
+            pg_user: str = os.environ.get(
+                'RD_OPTION_TERRAFORM_PG_BACKEND_USER'),
+            pg_password: str = os.environ.get(
+                'RD_OPTION_TERRAFORM_PG_BACKEND_PASSWORD'),
             pg_ip: str = os.environ.get('RD_OPTION_TERRAFORM_PG_BACKEND_IP'),
-            pg_port: str = os.environ.get('RD_OPTION_TERRAFORM_PG_BACKEND_PORT'),
+            pg_port: str = os.environ.get(
+                'RD_OPTION_TERRAFORM_PG_BACKEND_PORT'),
             pg_db: str = os.environ.get('RD_OPTION_TERRAFORM_PG_BACKEND_DB'),
-            deployment_action: str = os.environ.get("RD_OPTION_DEPLOYMENT_ACTION"),
+            deployment_action: str = os.environ.get(
+                "RD_OPTION_DEPLOYMENT_ACTION"),
             fqdn: str = os.environ.get("RD_OPTION_FQDN"),
             datacenter: str = os.environ.get('RD_OPTION_DATACENTER'),
             organization: str = os.environ.get('RD_OPTION_ORGANIZATION'),
-            terraform_cloud_token: str = os.environ.get('RD_OPTION_TERRAFORM_CLOUD_TOKEN'),
+            terraform_cloud_token: str = os.environ.get(
+                'RD_OPTION_TERRAFORM_CLOUD_TOKEN'),
             with_vcs_repo: str = os.environ.get('RD_OPTION_WITH_VCS_REPO'),
             auto_apply: str = os.environ.get('RD_OPTION_AUTO_APPLY'),
             execution_mode: str = os.environ.get('RD_OPTION_EXECUTION_MODE'),
-            deployment_environment: str = os.environ.get('RD_OPTION_DEPLOYMENT_ENVIRONMENT'),
-            vcs_repo_oauth_token_id: str = os.environ.get('RD_OPTION_VCS_REPO_OAUTH_TOKEN_ID'),
+            deployment_environment: str = os.environ.get(
+                'RD_OPTION_DEPLOYMENT_ENVIRONMENT'),
+            vcs_repo_oauth_token_id: str = os.environ.get(
+                'RD_OPTION_VCS_REPO_OAUTH_TOKEN_ID'),
             tag_names: str = os.environ.get('RD_OPTION_TAG_NAMES'),
-            terraform_code_dir: str = f"{os.path.expanduser('~')}/codebase/terraform/rootmodule/terraform_cloud_workspace",
+            terraform_code_dir: str = f"{os.path.expanduser('~')}/terraform/rootmodule/terraform_cloud_workspace",
     ):
 
         pg_backend_conn_str = f"postgres://{pg_user}:{pg_password}@{pg_ip}:{pg_port}/{pg_db}"
@@ -110,11 +119,11 @@ class RundeckJobs(object):
         try:
             zx.run_shell_print(
                 f"cd {config_dir_location} && \
-                terraform workspace select {fqdn}")
+                terraform workspace select {fqdn}.{deployment_environment}.{datacenter}")
         except:
             zx.run_shell_print(
                 f"cd {config_dir_location} && \
-                terraform workspace new {fqdn}")
+                terraform workspace new {fqdn}.{deployment_environment}.{datacenter}")
 
         plan_file_location = f"{config_dir_location}/config.plan"
 
@@ -129,9 +138,8 @@ class RundeckJobs(object):
                 terraform plan -destroy -out {plan_file_location} -input=false -var-file {vars_file_location} && \
                 terraform apply -input=false -auto-approve {plan_file_location} && \
                 terraform workspace select default && \
-                terraform workspace delete {fqdn}")
+                terraform workspace delete {fqdn}.{deployment_environment}.{datacenter}")
 
-    @logger.catch
     @retry(wait=wait_random(*wait_random_range), stop=stop_after_attempt(number_of_retries))
     def hcloud_web_solutions(
             self,
@@ -140,29 +148,44 @@ class RundeckJobs(object):
             organization: str = os.environ.get('RD_OPTION_ORGANIZATION'),
             auto_apply: str = os.environ.get('RD_OPTION_AUTO_APPLY'),
             execution_mode: str = os.environ.get('RD_OPTION_EXECUTION_MODE'),
-            deployment_environment: str = os.environ.get('RD_OPTION_DEPLOYMENT_ENVIRONMENT'),
-            deployment_action: str = os.environ.get("RD_OPTION_DEPLOYMENT_ACTION"),
+            deployment_environment: str = os.environ.get(
+                'RD_OPTION_DEPLOYMENT_ENVIRONMENT'),
+            deployment_action: str = os.environ.get(
+                "RD_OPTION_DEPLOYMENT_ACTION"),
             setup_wordpress: str = os.environ.get("RD_OPTION_SETUP_WORDPRESS"),
-            wordpress_site_title: str = os.environ.get("RD_OPTION_WORDPRESS_SITE_TITLE"),
-            with_wordpress_lifter_lms: str = os.environ.get("RD_OPTION_WITH_WORDPRESS_LIFTER_LMS"),
-            wordpress_lms_config_repo: str = os.environ.get("RD_OPTION_WORDPRESS_LMS_CONFIG_REPO"),
+            wordpress_site_title: str = os.environ.get(
+                "RD_OPTION_WORDPRESS_SITE_TITLE"),
+            with_wordpress_lifter_lms: str = os.environ.get(
+                "RD_OPTION_WITH_WORDPRESS_LIFTER_LMS"),
+            wordpress_lms_config_repo: str = os.environ.get(
+                "RD_OPTION_WORDPRESS_LMS_CONFIG_REPO"),
             wordpress_lms_config_repo_script_dir: str = os.environ.get(
                 "RD_OPTION_WORDPRESS_LMS_CONFIG_REPO_SCRIPT_DIR"),
             wordpress_lms_config_repo_script_name: str = os.environ.get(
                 "RD_OPTION_WORDPRESS_LMS_CONFIG_REPO_SCRIPT_NAME"),
-            with_lifter_lms_loadtest_course: str = os.environ.get("RD_OPTION_WITH_LIFTER_LMS_LOADTEST_COURSE"),
-            with_internal_mariadb: str = os.environ.get("RD_OPTION_WITH_INTERNAL_MARIADB"),
-            vault_login_username: str = os.environ.get("RD_OPTION_VAULT_LOGIN_USERNAME"),
-            vault_login_password: str = os.environ.get("RD_OPTION_VAULT_LOGIN_PASSWORD"),
-            atlas_mongo_public_key: str = os.environ.get("RD_OPTION_ATLAS_MONGO_PUBLIC_KEY"),
-            atlas_mongo_private_key: str = os.environ.get("RD_OPTION_ATLAS_MONGO_PRIVATE_KEY"),
-            web_server_image: str = os.environ.get("RD_OPTION_WEB_SERVER_IMAGE"),
-            mariadb_server_image: str = os.environ.get("RD_OPTION_MARIADB_SERVER_IMAGE"),
+            with_lifter_lms_loadtest_course: str = os.environ.get(
+                "RD_OPTION_WITH_LIFTER_LMS_LOADTEST_COURSE"),
+            with_internal_mariadb: str = os.environ.get(
+                "RD_OPTION_WITH_INTERNAL_MARIADB"),
+            vault_login_username: str = os.environ.get(
+                "RD_OPTION_VAULT_LOGIN_USERNAME"),
+            vault_login_password: str = os.environ.get(
+                "RD_OPTION_VAULT_LOGIN_PASSWORD"),
+            atlas_mongo_public_key: str = os.environ.get(
+                "RD_OPTION_ATLAS_MONGO_PUBLIC_KEY"),
+            atlas_mongo_private_key: str = os.environ.get(
+                "RD_OPTION_ATLAS_MONGO_PRIVATE_KEY"),
+            web_server_image: str = os.environ.get(
+                "RD_OPTION_WEB_SERVER_IMAGE"),
+            mariadb_server_image: str = os.environ.get(
+                "RD_OPTION_MARIADB_SERVER_IMAGE"),
             web_server_type: str = os.environ.get("RD_OPTION_WEB_SERVER_TYPE"),
-            mariadb_server_type: str = os.environ.get("RD_OPTION_MARIADB_SERVER_TYPE"),
+            mariadb_server_type: str = os.environ.get(
+                "RD_OPTION_MARIADB_SERVER_TYPE"),
             jira_issue_key: str = os.environ.get("RD_OPTION_JIRA_ISSUE_KEY"),
-            terraform_cloud_token: str = os.environ.get("RD_OPTION_TERRAFORM_CLOUD_TOKEN"),
-            terraform_code_dir: str = f"{os.path.expanduser('~')}/codebase/terraform/rootmodule/hcloud_web_solutions"
+            terraform_cloud_token: str = os.environ.get(
+                "RD_OPTION_TERRAFORM_CLOUD_TOKEN"),
+            terraform_code_dir: str = f"{os.path.expanduser('~')}/terraform/rootmodule/hcloud_web_solutions"
 
     ):
 
